Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(777)

Unified Diff: ui/aura/client/window_move_client.h

Issue 10828133: Desktop Aura: Allow tab drags out of window. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Cleanup Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_drag_controller.cc ('k') | ui/aura/root_window.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/client/window_move_client.h
diff --git a/ui/aura/client/window_move_client.h b/ui/aura/client/window_move_client.h
index b6f32a0920b91456401d47ee2d027275b8494104..048e572b747ea273c21637c2839652f1f4d6de33 100644
--- a/ui/aura/client/window_move_client.h
+++ b/ui/aura/client/window_move_client.h
@@ -7,6 +7,10 @@
#include "ui/aura/aura_export.h"
+namespace gfx {
+class Point;
+}
+
namespace aura {
class Window;
namespace client {
@@ -15,8 +19,9 @@ namespace client {
// window moving.
class AURA_EXPORT WindowMoveClient {
public:
- // Starts a nested message loop for moving the window.
- virtual void RunMoveLoop(Window* window) = 0;
+ // Starts a nested message loop for moving the window. |drag_offset| is the
+ // offset from the window origin to the cursor when the drag was started.
+ virtual void RunMoveLoop(Window* window, const gfx::Point& drag_offset) = 0;
// Ends a previously started move loop.
virtual void EndMoveLoop() = 0;
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_drag_controller.cc ('k') | ui/aura/root_window.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698